
extensions [array]

breed [Greenhouseowners Greenhouseowner]

globals [
  EnvironmentTechnologyList ; List with the four different technologies with for each technology a list with 5 products
  ImproveSameTech ; Necessary variable to overcome that every round the same product will be improved
  NumberOfBankruptedGreenhouseowners ; Variable to count the number of bankrupted greenhouseowners
  SumOfAllActualProduction ; Variable to some the total production of all the greenhouses together
  TechA ; Heater list with 5 different products/brands
  TechB ; CO2 Technology list with 5 different products/brands
  TechC ; Humidifier list with 5 different products/brands
  TechD ; Lights list with 5 different products/brands 
  NumberOfGreenhouseownersWithVeggies
  NumberOfGreenhouseownersWithFlowers
  RelativeProductionFlowers ;Actual Production / Potential Production, KPI of greenhouse
  RelativeProductionVeggies
  ProfitVeggies_depreciation ;The calculated Profit minus the depreciation of the currently used technologies
  ProfitFlowers_depreciation
  MeanProfitFlowers ; Average Profit for all existing greenhouse owners
  MeanProfitVeggies
  TechCounterVeggies ; shows a list with 4 arrays with 5 values, each value represents the number of used technologies at that tick (only for greenhouseowners with Veggies)
  TechCounterFlowers ; shows a list with 4 arrays with 5 values, each value represents the number of used technologies at that tick (only for greenhouseowners with Flowers)
  TechCounterTotal ; shows a list with 4 arrays with 5 values, each value represents the number of used technologies at that tick (for all the greenhouseowners)
  ProductChooser ;Supporting varable, used to randomly determine which Technology market is chosen per tick, that will improve a technology.
  MaxTech ; Supporting variable, used to keep track of the technology with the highest main function
]

Greenhouseowners-own [
  ActualProduction 
  BankAccount
  GreenhouseCroptype ; Either veggies or flowers
  GreenhouseTechnologyList ; List with four different technologies 
  OpinionLibrary ; List with 4 items with for each item five opinions (for each product one)
  TotalEnergyUse
  TotalTechdepreciation 
  LifetimeInitial ]

to setup
  clear-all
  CreateTechA ; Create the heaters
  CreateTechB ; Create the CO2 technologies
  CreateTechC ; Create the humidifiers
  CreateTechD ; Create the lights
  CreateEnvironmentTechnologyList ;List of all Technologymarkets
  CreateGreenhousenetwork ; Create number of greenhouseowners in a network
  set ImproveSameTech array:from-list n-values 4 [0]
  set NumberOfBankruptedGreenhouseowners 0 
  ask Greenhouseowners [GenerateGreenhouseownerProperties]
  reset-ticks
end

to CreateTechA ; the Heater
  ; This will automatically generate the different TechA-arrays with the following 10 properties 
  ; [influence temperature (vary-float TechA_TempMin-1), influence CO2 (vary-float 0-TechA_CO2Max), influence humidity (vary-float TechA_HumMin-0)
  ; influence light (vary-float 0 TechA_LightMax), energy use (vary-integer EnergyUseMin EnergyUseMax), cost price (vary-integer CostpriceMin CostpriceMax), lifespan (vary-integer LifespanMin LifespanMax),
  ; product number (0-4), technology number (0), 0] 
  set TechA []
  repeat 5 [
    set TechA lput array:from-list n-values 10 [0] TechA ]
  let ProductNumberA 0
  foreach TechA [
    array:set ? 0 vary-float TechA_TempMin 0.7
    array:set ? 1 vary-float 0 TechA_CO2Max
    array:set ? 2 vary-float TechA_HumMin 0
    array:set ? 3 vary-float 0 TechA_LightMax
    array:set ? 4 vary-integer EnergyUseMin EnergyUseMax
    array:set ? 5 vary-integer CostpriceMin CostpriceMax
    array:set ? 6 vary-integer LifespanMin LifespanMax 
    array:set ? 7 ProductNumberA
    array:set ? 8 0
    set ProductNumberA ProductNumberA + 1]
end

to CreateTechB ; The CO2 technology
  ; this will automatically generate the different TechB-arrays with the following properties 
  ; [influence temperature (vary-float 0 TechB_TempMax), influence CO2 (vary-float TechB_CO2Min 1), influence humidity (vary-float TechB_HumMin 0)
  ; influence light (vary-float TechB_LightMin 0), energy use (vary-integer EnergyUseMin EnergyUseMax), cost price (vary-integer CostpriceMin CostpriceMax), lifespan (vary-integer LifespanMin LifespanMax),    
  ; product number (0-4), technology number (1), 0] 
  set TechB []
  repeat 5 [
    set TechB lput array:from-list n-values 10 [0] TechB ]
  let ProductNumberB 0
  foreach TechB [
    array:set ? 0 vary-float 0 TechB_TempMax
    array:set ? 1 vary-float TechB_CO2Min 0.7
    array:set ? 2 vary-float TechB_HumMin 0
    array:set ? 3 vary-float TechB_LightMin 0
    array:set ? 4 vary-integer EnergyUseMin EnergyUseMax
    array:set ? 5 vary-integer CostpriceMin CostpriceMax
    array:set ? 6 vary-integer LifespanMin LifespanMax 
    array:set ? 7 ProductNumberB
    array:set ? 8 1
    set ProductNumberB ProductNumberB + 1]
end

to CreateTechC ; the Humidifier
  ; this will automatically generate the different TechC-arrays with the following properties 
  ; [influence temperature (vary-float 0 TechC_TempMax), influence CO2 (vary-float 0-TechC_CO2Max), influence humidity (vary-float TechC_HumMin 1)
  ; influence light (vary-float TechC_LightMin 0), energy use (vary-integer EnergyUseMin EnergyUseMax), cost price (vary-integer CostpriceMin CostpriceMax), lifespan (vary-integer LifespanMin LifespanMax)] 
  ; product number (0-4), technology number (2), 0]   
  set TechC []
  repeat 5 [
    set TechC lput array:from-list n-values 10 [0] TechC ]
  let ProductNumberC 0
  foreach TechC [
    array:set ? 0 vary-float 0 TechC_TempMax
    array:set ? 1 vary-float 0 TechC_CO2Max
    array:set ? 2 vary-float TechC_HumMin 0.7
    array:set ? 3 vary-float TechC_LightMin 0
    array:set ? 4 vary-integer EnergyUseMin EnergyUseMax
    array:set ? 5 vary-integer CostpriceMin CostpriceMax
    array:set ? 6 vary-integer LifespanMin LifespanMax 
    array:set ? 7 ProductNumberC
    array:set ? 8 2
    set ProductNumberC ProductNumberC + 1]
end  

to CreateTechD ; The Lights
  ; this will automatically generate the different TechD-arrays with the following properties 
  ; [influence temperature (vary-float 0 TechD_TempMax), influence CO2 (vary-float 0 TechD_CO2Max), influence humidity (vary-float TechD_HumMin 0)
  ; influence light (vary-float TechD_LightMin 1), energy use (vary-integer EnergyUseMin EnergyUseMax), cost price (vary-integer CostpriceMin CostpriceMax), lifespan (vary-integer LifespanMin LifespanMax)] 
  ; product number (0-4), technology number (3), 0] 
  set TechD []
  repeat 5 [
    set TechD lput array:from-list n-values 10 [0] TechD ]
  let ProductNumberD 0
  foreach TechD [
    array:set ? 0 vary-float 0 TechD_TempMax
    array:set ? 1 vary-float 0 TechD_CO2Max
    array:set ? 2 vary-float 0 TechD_HumMin 
    array:set ? 3 vary-float TechD_LightMin 0.7
    array:set ? 4 vary-integer EnergyUseMin EnergyUseMax
    array:set ? 5 vary-integer CostpriceMin CostpriceMax
    array:set ? 6 vary-integer LifespanMin LifespanMax 
    array:set ? 7 ProductNumberD
    array:set ? 8 3
    set ProductNumberD ProductNumberD + 1]
end  

to CreateEnvironmentTechnologyList
  set EnvironmentTechnologyList (list TechA TechB TechC TechD)
end

to CreateGreenhousenetwork ; taken from model library "Preferential Attachment"
  set-default-shape Greenhouseowners "circle"
  ifelse NumberOfGreenhouseowners = 1 [ 
    create-Greenhouseowners 1 ][
    create-Greenhouseowners 2 [set color red]
    ask one-of Greenhouseowners [create-link-with one-of other Greenhouseowners [set color white]]
    repeat (NumberOfGreenhouseowners - 2) [
      create-Greenhouseowners 1 [
        set color red
        let total random-float sum [count link-neighbors] of turtles
        let partner nobody
        ask other turtles [
          let nc count link-neighbors
          if partner = nobody [
            ifelse nc > total
              [ set partner self ]
              [ set total total - nc ]]]
        create-link-with partner [set color white]
        move-to partner
        fd 15 ]]]
    layout-radial turtles links max-one-of turtles [count my-links]
end

to GenerateGreenhouseownerProperties
   SetCroptype
   SetGreenhouseTechnologyList
   SetOpinionLibraries
   SetBankaccount  
   SetLifetimeInitial  
end

to SetCroptype
  let CroptypeDefiner random 2
  ifelse CroptypeDefiner = 0 
  [set GreenhouseCroptype "Veggies" ]
  [set GreenhouseCroptype "Flowers" ] 
end

to SetGreenhouseTechnologyList
    set GreenhouseTechnologyList []
    repeat 4 [
      set GreenhouseTechnologyList lput array:from-list n-values 10 [0] GreenhouseTechnologyList]
    let TechnologyPositionEnvironmentTechnologyList 0
    foreach GreenhouseTechnologyList [
      let ProductPositionTechList random 5
      array:set ? 0 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 0
      array:set ? 1 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 1
      array:set ? 2 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 2
      array:set ? 3 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 3
      array:set ? 4 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 4
      array:set ? 5 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 5
      array:set ? 6 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 6
      array:set ? 7 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 7
      array:set ? 8 array:item (item ProductPositionTechList (item TechnologyPositionEnvironmentTechnologyList EnvironmentTechnologyList)) 8       
      set TechnologyPositionEnvironmentTechnologyList TechnologyPositionEnvironmentTechnologyList + 1]   
end

to SetOpinionLibraries
   set OpinionLibrary []
   repeat 4 [
    set OpinionLibrary lput array:from-list n-values 5 [0] OpinionLibrary ]
end

to SetBankaccount 
  set Bankaccount InitialBankaccount
end

to SetLifetimeInitial ;;Used to calculate the depreciation of technologies
  set LifetimeInitial array:from-list n-values 4 [0] 
  let LifetimeInitialCounter 0
  repeat 4 [
    array:set LifetimeInitial LifetimeInitialCounter array:item (item LifetimeInitialCounter GreenhouseTechnologylist) 6 
    set LifetimeInitialCounter LifetimeInitialCounter + 1]
end

to go
  set RelativeProductionVeggies 0
  set RelativeProductionFlowers 0
  EmptyTechCounters ;  Create the lists and arrays to keep track of the numbers of purchased Techs 
  ask Greenhouseowners [
    AdaptTechCounters
    CalculateProduction
    CalculateTotalEnergyUse
    UpdateBankaccount
    ReviseOpinions ]
  ImproveTechnologies
  ask Greenhouseowners [
    ShareOpinions ] ; and update opinion library
  ask Greenhouseowners [
    PurchaseNewTechnologies] ; only when lifetime is equal to zero and when Bankaccount is high enough
  ask Greenhouseowners [
    AdjustLifetimeTechnologies] ; every lifetime (index 6) minus 1
  Visualize
  update-plots
  tick  
  set NumberOfGreenhouseownersWithVeggies 0
  set NumberOfGreenhouseownersWithFlowers 0
end

to Visualize
  let TotalProfitVeggies 0
  let TotalProfitFlowers 0
  if NumberOfGreenhouseownersWithVeggies > 0 [set RelativeProductionVeggies (RelativeProductionVeggies / NumberOfGreenhouseownersWithVeggies)]
  if NumberOfGreenhouseownersWithVeggies > 0 [set RelativeProductionFlowers (RelativeProductionFlowers / NumberOfGreenhouseownersWithFlowers)]
  ask Greenhouseowners [ifelse GreenhouseCroptype = "Veggies" [set TotalProfitVeggies (TotalProfitVeggies + ProfitVeggies_depreciation)] [set TotalProfitFlowers (TotalProfitFlowers + ProfitFlowers_depreciation)]]
  set MeanProfitVeggies (TotalProfitVeggies / NumberOfGreenhouseownersWithVeggies)
  set MeanProfitFlowers (TotalProfitFlowers / NumberOfGreenhouseownersWithFlowers)
  if WhatKindOfCroptype? [
    ask greenhouseowners [
      if GreenhouseCroptype = "Veggies" [set color green]
      if GreenhouseCroptype = "Flowers" [set color red] ]]   
  if WhatKindOfProductNumber? [
    ask greenhouseowners [
      if array:item (item 0 GreenhouseTechnologyList) 7 = 0 [set shape "die 1"] 
      if array:item (item 0 GreenhouseTechnologyList) 7 = 1 [set shape "die 2"] 
      if array:item (item 0 GreenhouseTechnologyList) 7 = 2 [set shape "die 3"] 
      if array:item (item 0 GreenhouseTechnologyList) 7 = 3 [set shape "die 4"] 
      if array:item (item 0 GreenhouseTechnologyList) 7 = 4 [set shape "die 5"] ]]
end

to EmptyTechCounters ;;Used to reset the counters that keep track of the number technologies are bought
  set TechCounterVeggies []
  set TechCounterFlowers []
  set TechCounterTotal []
  repeat 4 [
      set TechCounterVeggies lput array:from-list n-values 5 [0] TechCounterVeggies
      set TechCounterFlowers lput array:from-list n-values 5 [0] TechCounterFlowers
      set TechCounterTotal lput array:from-list n-values 5 [0] TechCounterTotal ] 
end

to AdaptTechCounters ;;Counter that keeps track of the number technologies are bought.
  let TechCounterTechPosition 0
  repeat 4 [
    ifelse GreenhouseCroptype = "Veggies" 
    [array:set item TechCounterTechPosition TechCounterVeggies array:item item TechCounterTechPosition GreenhouseTechnologyList 7 array:item item TechCounterTechPosition TechCounterVeggies array:item item TechCounterTechPosition GreenhouseTechnologyList 7 + 1]
    [array:set item TechCounterTechPosition TechCounterFlowers array:item item TechCounterTechPosition GreenhouseTechnologyList 7 array:item item TechCounterTechPosition TechCounterFlowers array:item item TechCounterTechPosition GreenhouseTechnologyList 7 + 1]
    array:set item TechCounterTechPosition TechCounterTotal array:item item TechCounterTechPosition GreenhouseTechnologyList 7 array:item item TechCounterTechPosition TechCounterTotal array:item item TechCounterTechPosition GreenhouseTechnologyList 7 + 1
    set TechCounterTechPosition TechCounterTechPosition + 1 ]
end

to CalculateProduction 
  ;;First, the investments in crop seeds are extracted from the Bank account (investments in seeds are: Potential Growth x Purchase Price)
  ifelse GreenhouseCroptype = "Veggies" [set Bankaccount Bankaccount - VeggiesPotentialGrowth * VeggiesPurchasePrice] [set Bankaccount Bankaccount - FlowersPotentialGrowth * FlowersPurchasePrice] 
  
  let TempFraction 0
  let CO2Fraction 0
  let HumFraction 0
  let LightFraction 0
  let InfluencePosition 0
  let InfluencePositionArray array:from-list n-values 4 [0]
  
  ; Calculate the sum of all Tech influence numbers. The max. total influence is 1. At 1, the Ideal climate = Internal climate.
  repeat 4 [
  ifelse array:item (item 0 GreenhouseTechnologyList) InfluencePosition + array:item (item 1 GreenhouseTechnologyList) InfluencePosition + array:item (item 2 GreenhouseTechnologyList) InfluencePosition + array:item (item 3 GreenhouseTechnologyList) InfluencePosition > 1 [array:set InfluencePositionArray InfluencePosition 1] 
  [array:set InfluencePositionArray InfluencePosition array:item (item 0 GreenhouseTechnologyList) InfluencePosition + array:item (item 1 GreenhouseTechnologyList) InfluencePosition + array:item (item 2 GreenhouseTechnologyList) InfluencePosition + array:item (item 3 GreenhouseTechnologyList) InfluencePosition]
  set InfluencePosition InfluencePosition + 1 ]
  Ifelse GreenhouseCroptype = "Veggies" [  
    set NumberOfGreenhouseownersWithVeggies NumberOfGreenhouseownersWithVeggies + 1
    
    set ActualProduction VeggiesPotentialGrowth * mean (list 
      (1 - ((abs (ExternalTemp - VeggiesIdealTemp) / VeggiesIdealTemp - array:item InfluencePositionArray 0 * (abs (ExternalTemp - VeggiesIdealTemp) / VeggiesIdealTemp))))
      (1 - ((abs (ExternalCO2 - VeggiesIdealCO2) / VeggiesIdealCO2 - array:item InfluencePositionArray 1 * (abs (ExternalCO2 - VeggiesIdealCO2) / VeggiesIdealCO2))))  
      (1 - ((abs (ExternalHum - VeggiesIdealHum) / VeggiesIdealHum - array:item InfluencePositionArray 2 * (abs (ExternalHum - VeggiesIdealHum) / VeggiesIdealHum))))
      (1 - ((abs (ExternalLight - VeggiesIdealLight) / VeggiesIdealLight - array:item InfluencePositionArray 3 * (abs (ExternalLight - VeggiesIdealLight) / VeggiesIdealLight))))) 
    set RelativeProductionVeggies RelativeProductionVeggies + ActualProduction / VeggiesPotentialGrowth ]
  
  [set NumberOfGreenhouseownersWithFlowers NumberOfGreenhouseownersWithFlowers + 1

    set ActualProduction FlowersPotentialGrowth * mean (list 
      (1 - ((abs (ExternalTemp - FlowersIdealTemp) / FlowersIdealTemp - array:item InfluencePositionArray 0 * (abs (ExternalTemp - FlowersIdealTemp) / FlowersIdealTemp))))
      (1 - ((abs (ExternalCO2 - FlowersIdealCO2) / FlowersIdealCO2 - array:item InfluencePositionArray 1 * (abs (ExternalCO2 - FlowersIdealCO2) / FlowersIdealCO2))))  
      (1 - ((abs (ExternalHum - FlowersIdealHum) / FlowersIdealHum - array:item InfluencePositionArray 2 * (abs (ExternalHum - FlowersIdealHum) / FlowersIdealHum))))
      (1 - ((abs (ExternalLight - FlowersIdealLight) / FlowersIdealLight - array:item InfluencePositionArray 3 * (abs (ExternalLight - FlowersIdealLight) / FlowersIdealLight))))) 
    set RelativeProductionFlowers RelativeProductionFlowers + ActualProduction / FlowersPotentialGrowth ]
end

to CalculateTotalEnergyUse
    set TotalEnergyUse (array:item (item 0 GreenhouseTechnologyList) 4 + array:item (item 1 GreenhouseTechnologyList) 4 + array:item (item 2 GreenhouseTechnologyList) 4 + array:item (item 3 GreenhouseTechnologyList) 4)
end

to UpdateBankaccount
  ifelse GreenhouseCroptype = "Veggies" [set Bankaccount Bankaccount + ActualProduction * VeggiesMarketPrice - TotalEnergyUse * FuelPrice] [set Bankaccount Bankaccount + ActualProduction * FlowersMarketPrice - TotalEnergyUse * FuelPrice] 
  ; The Total depreciation is calculated with the sum of all technology costs in use, devided by the initial Lifetime of those technologies
  ; The Techdepreciation counter is used to iterate the same proces for all the four used technologies
  let DepreciationCounter 0
  repeat 4 [ 
    set TotalTechdepreciation (array:item (item DepreciationCounter GreenhouseTechnologylist) 5 / (array:item LifetimeInitial DepreciationCounter)) 
    set DepreciationCounter DepreciationCounter + 1]
  
  ifelse GreenhouseCroptype = "Veggies" [set ProfitVeggies_depreciation ((ActualProduction * VeggiesMarketPrice - TotalEnergyUse * FuelPrice) - TotalTechdepreciation)] [set ProfitFlowers_depreciation ((ActualProduction * FlowersMarketPrice - TotalEnergyUse * FuelPrice) - TotalTechdepreciation)]
end

to ReviseOpinions
   let PositionOpinionList []
   
   ;ReviseOpinions
   foreach GreenhouseTechnologyList [
     set PositionOpinionList lput array:item ? 7 PositionOpinionList]
   
   let PositionOpinionArray array:from-list PositionOpinionList
   let ParticularPositionOpinionArray 0
   
   ifelse GreenhouseCropType = "Veggies" 
   [foreach OpinionLibrary [
       ifelse ticks = 0 
       [array:set ? array:item PositionOpinionArray ParticularPositionOpinionArray ActualProduction / VeggiesPotentialGrowth]
       [array:set ? array:item PositionOpinionArray ParticularPositionOpinionArray (array:item ? array:item PositionOpinionArray ParticularPositionOpinionArray + (ActualProduction / VeggiesPotentialGrowth)) / 2]
       set ParticularPositionOpinionArray ParticularPositionOpinionArray + 1 ] ]
   
   [foreach OpinionLibrary [
       ifelse ticks = 0 
       [array:set ? array:item PositionOpinionArray ParticularPositionOpinionArray ActualProduction / FlowersPotentialGrowth]
       [array:set ? array:item PositionOpinionArray ParticularPositionOpinionArray (array:item ? array:item PositionOpinionArray ParticularPositionOpinionArray + (ActualProduction / FlowersPotentialGrowth)) / 2]
       set ParticularPositionOpinionArray ParticularPositionOpinionArray + 1 ] ]  
end

to ShareOpinions
  ask link-neighbors [
    if GreenhouseCroptype = [GreenhouseCroptype] of myself [
    let OpinionTechPosition 0
    foreach [OpinionLibrary] of myself [
      let OpinionLibraryTemporary ? 
      let OpinionProductPosition 0
      repeat 5 [
        if array:item (item OpinionTechPosition OpinionLibrary) OpinionProductPosition = 0 
        [array:set (item OpinionTechPosition OpinionLibrary) OpinionProductPosition (array:item OpinionLibraryTemporary OpinionProductPosition * StubbornnessFactor)] 
        if array:item (item OpinionTechPosition OpinionLibrary) OpinionProductPosition > 0 and array:item OpinionLibraryTemporary OpinionProductPosition > 0
        [array:set (item OpinionTechPosition OpinionLibrary) OpinionProductPosition (array:item (item OpinionTechPosition OpinionLibrary) OpinionProductPosition + StubbornnessFactor * array:item OpinionLibraryTemporary OpinionProductPosition) / (1 + StubbornnessFactor)  ]
        set OpinionProductPosition OpinionProductPosition + 1] 
      set OpinionTechPosition OpinionTechPosition + 1] ] ]
end

to PurchaseNewTechnologies
  foreach GreenhouseTechnologyList [
   if array:item ? 6 = 0 [
     let TechnologyToPurchase array:item ? 8
     let HighestOpinion 0
     let ProductCounter 0
     let ProductNumberToBuy 0
     repeat 5 [
       IF array:item (item TechnologyToPurchase OpinionLibrary) ProductCounter > HighestOpinion 
       [set HighestOpinion array:item (item TechnologyToPurchase OpinionLibrary) ProductCounter set ProductNumberToBuy ProductCounter]
       set ProductCounter ProductCounter + 1 ]
     
     ifelse Bankaccount >= array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 5 
     [ array:set ? 0 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 0
       array:set ? 1 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 1
       array:set ? 2 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 2
       array:set ? 3 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 3
       array:set ? 4 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 4
       array:set ? 5 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 5
       array:set ? 6 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 6
       array:set ? 7 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 7
       array:set ? 8 array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 8
       array:set ? 9 1 
       set Bankaccount Bankaccount - array:item (item ProductNumberToBuy (item TechnologyToPurchase EnvironmentTechnologyList)) 5]
     
     [let PositionCheapTechnologiesList []
       let PositionCheapTechnologyDefiner 0
       repeat 5 [
         if Bankaccount >= array:item (item PositionCheapTechnologyDefiner (item TechnologyToPurchase EnvironmentTechnologyList)) 5 [
           set PositionCheapTechnologiesList lput PositionCheapTechnologyDefiner PositionCheapTechnologiesList]]
       ifelse empty? PositionCheapTechnologiesList [ReplaceGreenhouseowner]
       [let ProductNumberToBuyFromCheapestOptions one-of PositionCheapTechnologiesList
         array:set ? 0 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 0
         array:set ? 1 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 1
         array:set ? 2 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 2
         array:set ? 3 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 3
         array:set ? 4 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 4
         array:set ? 5 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 5
         array:set ? 6 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 6
         array:set ? 7 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 7
         array:set ? 8 array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 8
         array:set ? 9 1 
         set Bankaccount Bankaccount - array:item (item ProductNumberToBuyFromCheapestOptions (item TechnologyToPurchase EnvironmentTechnologyList)) 5] ]
                  ]]
end
  
to ReplaceGreenhouseowner 
  set NumberOfBankruptedGreenhouseowners NumberOfBankruptedGreenhouseowners + 1    
  SetCroptype
  SetGreenhouseTechnologyList
  SetOpinionLibraries
  SetBankaccount   
end
  
to AdjustLifetimeTechnologies
  foreach GreenHouseTechnologyList [
    if array:item ? 9 = 0 [array:set ? 6 array:item ? 6 - 1] ]
  foreach GreenhouseTechnologyList [
    array:set ? 9 0 ]
end 

to ImproveTechnologies 
  ; determine which Tech to improve: 0=A; 1=B; 2=C, 3=D
  set ProductChooser random 4
  set MaxTech 0 
  
  ; define how many times a certain product is improved in a row
  ifelse array:item ImproveSameTech ProductChooser < ImproveSameTechCounter
  
  ; if this number is < than ImproveSameTechCounter Select a Tech != random else = random
  [ifelse DevelopmentStyle = "Open source cooperation" [SelectTechOption2] [SelectTechOption1]]
  [SelectTechOptionRandom]
end

to SelectTechOption1
  ; look for highest main function of all the products and store it as MaxTech
  foreach item ProductChooser EnvironmentTechnologyList [
    IF array:item ? ProductChooser > MaxTech [set MaxTech array:item ? ProductChooser]]
  array:set ImproveSameTech ProductChooser array:item ImproveSameTech ProductChooser + 1
  ImproveTech
end

to SelectTechOption2
  ; look for the best performing greenhouse, and select his product of the chosen technology
  let HighestPerformance 0
  ask Greenhouseowners [if ActualProduction > HighestPerformance [set HighestPerformance ActualProduction set MaxTech array:item (item ProductChooser GreenhouseTechnologyList) ProductChooser]]
  ImproveTech
end

to SelectTechOptionRandom
  let ImproveRandomTech random 5
  set MaxTech array:item (item ImproveRandomTech (item ProductChooser EnvironmentTechnologyList)) ProductChooser
  
  let MaxTechTemporary 0
  ifelse DevelopmentStyle = "Open source cooperation"
 
  ; if Open Source Cooperation find highest main function  
  [foreach item ProductChooser EnvironmentTechnologyList [
    IF array:item ? ProductChooser > MaxTechTemporary [set MaxTechTemporary array:item ? ProductChooser]]]
  
  ; if Protected development or Limited Cooperation find best performing greenhouse
  [let HighestPerformance 0
    ask Greenhouseowners [if ActualProduction > HighestPerformance [set HighestPerformance ActualProduction set MaxTechTemporary array:item (item ProductChooser GreenhouseTechnologyList) ProductChooser]]]

  if MaxTech != MaxTechTemporary [array:set ImproveSameTech ProductChooser 0]
  ImproveTech
end

to ImproveTech
  ; for every selected technology
  foreach item ProductChooser EnvironmentTechnologyList [
    
    ; if the the main function of one of the product of that selected technology is equal to the MaxTech
    IF array:item ? ProductChooser = MaxTech [
      let TechCopyList [] 
      let TechCopyListCounter 0
      
      ; create three empty Lists
      repeat 3 [
        set TechCopyList lput array:from-list n-values 10 [0] TechCopyList ]
      
      ; fill the empty lists with 5 values
      repeat 3 [
        array:set item TechCopyListCounter TechCopyList 0 array:item ? 0
        array:set item TechCopyListCounter TechCopyList 1 array:item ? 1
        array:set item TechCopyListCounter TechCopyList 2 array:item ? 2
        array:set item TechCopyListCounter TechCopyList 3 array:item ? 3
        array:set item TechCopyListCounter TechCopyList 5 array:item ? 5
        set TechCopyListCounter TechCopyListCounter + 1 ]  
      
      let SumInfluencesTech 0
      let MaxSumInfluencesTech 0
      let LimitedPositionCounterTech 0
      let NewTech 0
      foreach TechCopyList [
        
        ; improve main function
        ifelse array:item ? ProductChooser >= 1 [array:set ? ProductChooser 1] [array:set ? ProductChooser array:item ? ProductChooser + random-float InfluenceRangeMain] 
        
        ; randomly change secondary functions
        
        ; change TechA
        if ProductChooser = 0 [
          ifelse array:item ? 1 <= 0 [array:set ? 1 array:item ? 1 + random-float InfluenceRangeSec] [array:set ? 1 array:item ? 1 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 1 >= TechA_CO2Max [array:set ? 1 array:item ? 1 - random-float InfluenceRangeSec] 
      
          ifelse array:item ? 2 >= 0 [array:set ? 2 array:item ? 2 - random-float InfluenceRangeSec] [array:set ? 2 array:item ? 2 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 2 <= TechA_HumMin [array:set ? 2 array:item ? 2 + random-float InfluenceRangeSec] ]
        
        ; change TechB and TechD
        if ProductChooser = 1 or ProductChooser = 3 [
          ifelse array:item ? 0 <= 0 [array:set ? 0 array:item ? 0 + random-float InfluenceRangeSec] [array:set ? 0 array:item ? 0 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 0 >= TechB_TempMax [array:set ? 0 array:item ? 0 - random-float InfluenceRangeSec] 
      
          ifelse array:item ? 2 >= 0 [array:set ? 2 array:item ? 2 - random-float InfluenceRangeSec] [array:set ? 2 array:item ? 2 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 2 <= TechB_HumMin [array:set ? 2 array:item ? 2 + random-float InfluenceRangeSec] ]
        
        ; change TechC
        if ProductChooser = 2 [
          ifelse array:item ? 0 <= 0 [array:set ? 0 array:item ? 0 + random-float InfluenceRangeSec] [array:set ? 0 array:item ? 0 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 0 >= TechC_TempMax [array:set ? 0 array:item ? 0 - random-float InfluenceRangeSec] 
    
          ifelse array:item ? 3 >= 0 [array:set ? 3 array:item ? 3 - random-float InfluenceRangeSec] [array:set ? 3 array:item ? 3 + vary-float (-1 * InfluenceRangeSec) InfluenceRangeSec] 
          if array:item ? 3 <= TechC_LightMin [array:set ? 3 array:item ? 3 + random-float InfluenceRangeSec] ]
        
        ; increase cost price of adapted technology   
        array:set ? 5 array:item ? 5 + (random CostPriceRange * CostPriceCooperativeMultiplicator)
        
        Ifelse DevelopmentStyle = "Protected development" 
        
        ; replace the product with highest main function
        [set SumInfluencesTech array:item ? ProductChooser] 
        
        ; replace the product with highest sum of all functions
        [set SumInfluencesTech array:item ? 0 + array:item ? 1 + array:item ? 2 + array:item ? 3]
        
        ; select product with heighest SumInfluencesTech
        if SumInfluencesTech > MaxSumInfluencesTech [set MaxSumInfluencesTech SumInfluencesTech set NewTech LimitedPositionCounterTech]
        set LimitedPositionCounterTech LimitedPositionCounterTech + 1 ]
      
      ; adapt the previous product with the best improved copy
      
      array:set ? 0 array:item (item NewTech TechCopyList) 0
      array:set ? 1 array:item (item NewTech TechCopyList) 1
      array:set ? 2 array:item (item NewTech TechCopyList) 2
      array:set ? 5 array:item (item NewTech TechCopyList) 5 ]]
end

to-report vary-float [#low #high] ; random float in given range
   report #low + random-float (#high - #low )
end 

to-report vary-integer [#low #high] ; random integer in given range
   report #low + random (#high - #low + 1)
end 
@#$#@#$#@
GRAPHICS-WINDOW
918
139
1494
667
16
14
17.152
1
24
1
1
1
0
1
1
1
-16
16
-14
14
1
1
1
ticks
30.0

BUTTON
149
143
212
176
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
31
145
97
178
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
39
193
210
238
DevelopmentStyle
DevelopmentStyle
"Protected development" "Limited cooperation" "Open source cooperation"
2

SLIDER
39
342
210
375
TechA_TempMin
TechA_TempMin
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
39
376
209
409
TechA_CO2Max
TechA_CO2Max
0
0.5
0.05
0.05
1
NIL
HORIZONTAL

SLIDER
39
409
210
442
TechA_HumMin
TechA_HumMin
-0.5
0
-0.05
0.05
1
NIL
HORIZONTAL

SLIDER
735
245
903
278
LifespanMin
LifespanMin
0
4
3
1
1
NIL
HORIZONTAL

SLIDER
39
276
209
309
InfluenceRangeMain
InfluenceRangeMain
0
0.1
0.02
0.02
1
NIL
HORIZONTAL

SLIDER
560
279
733
312
CostpriceMax
CostpriceMax
1500
2000
1500
100
1
NIL
HORIZONTAL

SLIDER
560
245
733
278
CostPriceMin
CostPriceMin
1000
1500
1500
100
1
NIL
HORIZONTAL

SLIDER
39
241
209
274
InfluenceRangeSec
InfluenceRangeSec
0
0.05
0.04
0.01
1
NIL
HORIZONTAL

SLIDER
387
245
560
278
EnergyUseMin
EnergyUseMin
0
5000
0
1000
1
NIL
HORIZONTAL

SLIDER
387
279
560
312
EnergyUseMax
EnergyUseMax
5000
10000
5000
1000
1
NIL
HORIZONTAL

SLIDER
212
277
384
310
ImproveSameTechCounter
ImproveSameTechCounter
0
5
4
1
1
NIL
HORIZONTAL

SLIDER
212
243
384
276
CostPriceRange
CostPriceRange
0
1000
400
100
1
NIL
HORIZONTAL

SLIDER
40
444
209
477
TechA_LightMax
TechA_LightMax
0
0.1
0
0.1
1
NIL
HORIZONTAL

SLIDER
387
343
560
376
TechC_TempMax
TechC_TempMax
0
0.2
0.05
0.05
1
NIL
HORIZONTAL

SLIDER
388
378
562
411
TechC_CO2Max
TechC_CO2Max
0
0.1
0
0.01
1
NIL
HORIZONTAL

SLIDER
389
413
562
446
TechC_HumMin
TechC_HumMin
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
389
447
562
480
TechC_LightMin
TechC_LightMin
-0.3
0
-0.05
0.05
1
NIL
HORIZONTAL

SLIDER
736
280
905
313
LifespanMax
LifespanMax
4
10
5
1
1
NIL
HORIZONTAL

SLIDER
213
342
386
375
TechB_TempMax
TechB_TempMax
0
0.2
0.05
0.05
1
NIL
HORIZONTAL

SLIDER
213
376
386
409
TechB_CO2Min
TechB_CO2Min
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
214
412
387
445
TechB_HumMin
TechB_HumMin
-0.3
0
-0.05
0.05
1
NIL
HORIZONTAL

SLIDER
215
446
388
479
TechB_LightMin
TechB_LightMin
-0.3
0
0
0.1
1
NIL
HORIZONTAL

SLIDER
563
344
736
377
TechD_TempMax
TechD_TempMax
0
0.1
0.05
0.05
1
NIL
HORIZONTAL

SLIDER
564
378
737
411
TechD_CO2Max
TechD_CO2Max
0
0.2
0
0.1
1
NIL
HORIZONTAL

SLIDER
564
413
737
446
TechD_HumMin
TechD_HumMin
-0.2
0
-0.05
0.05
1
NIL
HORIZONTAL

SLIDER
565
447
738
480
TechD_LightMin
TechD_LightMin
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
41
516
209
549
VeggiesIdealTemp
VeggiesIdealTemp
0
40
26
1
1
NIL
HORIZONTAL

SLIDER
41
550
209
583
VeggiesIdealCO2
VeggiesIdealCO2
1000
2000
1500
100
1
NIL
HORIZONTAL

SLIDER
42
584
210
617
VeggiesIdealHum
VeggiesIdealHum
0
100
75
1
1
NIL
HORIZONTAL

SLIDER
43
618
210
651
VeggiesIdealLight
VeggiesIdealLight
1000
2000
1400
200
1
NIL
HORIZONTAL

SLIDER
212
517
378
550
FlowersIdealTemp
FlowersIdealTemp
0
35
24
1
1
NIL
HORIZONTAL

SLIDER
212
551
378
584
FlowersIdealCO2
FlowersIdealCO2
1000
2000
1200
200
1
NIL
HORIZONTAL

SLIDER
212
585
378
618
FlowersIdealHum
FlowersIdealHum
0
100
87
1
1
NIL
HORIZONTAL

SLIDER
212
619
379
652
FlowersIdealLight
FlowersIdealLight
1000
2000
1700
100
1
NIL
HORIZONTAL

SLIDER
212
653
378
686
FlowersPotentialGrowth
FlowersPotentialGrowth
0
1000
900
100
1
NIL
HORIZONTAL

SLIDER
43
652
210
685
VeggiesPotentialGrowth
VeggiesPotentialGrowth
0
1000
900
100
1
NIL
HORIZONTAL

SLIDER
387
210
557
243
NumberOfGreenhouseowners
NumberOfGreenhouseowners
0
100
150
1
1
NIL
HORIZONTAL

SLIDER
561
211
732
244
InitialBankaccount
InitialBankaccount
0
100000
70000
10000
1
NIL
HORIZONTAL

SLIDER
379
517
551
550
ExternalTemp
ExternalTemp
0
100
17
1
1
NIL
HORIZONTAL

SLIDER
380
551
552
584
ExternalCO2
ExternalCO2
200
2000
400
200
1
NIL
HORIZONTAL

SLIDER
381
585
553
618
ExternalHum
ExternalHum
50
100
74
1
1
NIL
HORIZONTAL

SLIDER
382
619
554
652
ExternalLight
ExternalLight
800
2000
1000
100
1
NIL
HORIZONTAL

SLIDER
213
208
383
241
StubbornnessFactor
StubbornnessFactor
0.7
0.9
1
0.1
1
NIL
HORIZONTAL

SLIDER
556
518
728
551
FuelPrice
FuelPrice
0.4
1.0
0.8
0.2
1
NIL
HORIZONTAL

SLIDER
556
553
729
586
VeggiesMarketPrice
VeggiesMarketPrice
0
20
15
5
1
NIL
HORIZONTAL

SLIDER
557
587
729
620
FlowersMarketPrice
FlowersMarketPrice
0
20
15
5
1
NIL
HORIZONTAL

SWITCH
915
37
1148
70
WhatKindOfCroptype?
WhatKindOfCroptype?
0
1
-1000

SWITCH
915
74
1148
107
WhatKindOfProductNumber?
WhatKindOfProductNumber?
0
1
-1000

SLIDER
557
621
729
654
VeggiesPurchasePrice
VeggiesPurchasePrice
0
20
3
1
1
NIL
HORIZONTAL

SLIDER
557
658
730
691
FlowersPurchasePrice
FlowersPurchasePrice
0
20
3
1
1
NIL
HORIZONTAL

SLIDER
735
210
902
243
CostPriceCooperativeMultiplicator
CostPriceCooperativeMultiplicator
0
2
1.3
0.1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT
This model presents a Greenhouse horticultural sector, where Greenhouse owners, the agents, purchase new technologies, developed by different Technology markets. The Greenhouse owners try to increase their crop yield and profit by selecting technologies that are capable in better approaching the optimal internal climate. The less the internal condition deviates from the prefered condition for the cultivated croptype, the higher the actual production will be. Greenhouse owners form an opinion about a technology and share their opinions with neighbors. Technology markets frequently update their technologies according to one of the three development styles.

### Purpose of Model
Greenhouses exist of different components, the technologies, which together work to attain the prefered internal climate in the greenhouse. In reality, technologies often are developed in isolation, because this is cheaper and there is assumed that each technologies only influences a specific part of the internal climate and that they do not mutually influence each others performance. However, it is plausible that for instance a heater not only influences temperature, but also the CO2 concentration and humidity. Technologies will influence more components of the internal climate than taken into account with the design. If technologies interact with each, the internal condition will be an emergent property from this interactions and the actual performance might differ from the designed performance. The sum of the partial performances will in this way differ from the actual performance.

The goal of the model is to investigate the performance of a greenhouse as an emergent property of the interactions between different technologies under different development styles: Protected development, limited cooperation, and open source cooperation.

The research question is: What is the influence of different development styles on the performance of greenhouses and which style leads to the highest performance, under which circumstances?

### Main Modelling assumptions
-The market price is external, because the greenhouse owners will not be able to influence it by changing their output. The output of the sector is neglectible small compared to the total output.
-Technology markets are part of the environment. They are not influenced by the Greenhouse owners and behave independently, but influence the owners and are therefore relevant to incorporate into the system.
-Technologies can only be bought when the lifespan is equal to zero.
-Greenhouse owners cannot change their crop type. In reality, greenhouse owners also rarely shift to another crop type.
-Bankrupted greenhouses reset their properties to the basic values, to represent that they start over again.
-Greenhouse owners only share their opinion with their neighbors with which they are direct connected, their are no different Information sharing strategies.
-Technologies are only bought if the budget is sufficient. Only technologies which fall within the budget are selected to buy.
-Technologies are bought based on an opinion. A technology that is never been used before by the greenhouse owner himself or his neighbors, will have an opinion equal to zero. In this way, the owner only will buy a technology that he 'knows', from his neighbors or by experience.
-The Opinion is the average of the neighbors opinions multiplied with stubborness factor, and the own opinion. 
The own opinion is based on the fraction of the actual production and the potential yield. The opinion of a neighbor will be multiplied by a certain stubbornness factor, summed up by this own opinion, and divided by two. Stubbornness represents the relative weight the Greenhouse owner values the opinion of his neighbors less in comparison with his own opinion.

## HOW IT WORKS

### Actions Technology markets

Technologymarkets improve their technology based on the selected experimental development style. Each Technology market improves with the following steps:
1. Select the technology
   a. With the highest main function
   b. From the best performing greenhouse
2. Create three copies and for each copy, improve the main function and the secundary       functions randomly. 
3. Select one of the three copies with
   a. the highest main function
   b. the highest sum of all main and secundary functions
4. Replace the old technology with the improved one

##### Protected development 
Competitive development in isolation, ignores the existence of epistatic effects. The main function of a technology is improved and the other functions are randomly changed, because an isolated developer does not know the side effects of his own technology.
Protected Development consists therefore of the following procedures:
- 1a 
- 3a
##### Limited cooperation
Developers are able to know the side effects of their own technologies and can take this into account when updating.Therefore the technology with the highest sum of all functions, with the highest overall performance is selected. The procedures are:
- 1a
- 3b
##### Open Source cooperation
Technology markets are able to know the actual performance of the greenhouse owners. Information about the performance is exchanged between the developer and the greenhouse owners. Each Technology market improves its product that operates in the best performing greenhouse. Because there is also cooperated, the technology with the highest sum of all influences is selected.
- 1b
- 3b

### Actions Greenhouse Owner

Every tick, each Greenhouse owner:
-Calculates his production, based on the ideal growth conditions of the croptype and the available technologies.
-Calculates his total energy use, equals the sum of the energy use of the used technologies.
-Update his bank account, by calculating his revenue, his energy costs and his profit. If his Bank account becomes negative, he goes bankrupt and replaces himself.
-Revises his opinion. First, he form his Own Opinion about a croptype, based on the fraction of the actual and the potential yield. Secondly, he ask his neighbors (only if this neighbor has the same croptype) to change their opinions based on his opinions. 
-Purchases new technologies, to replace the technologies which are over aged. The Greenhouse owner selects the technology which about he has formed the highest opinion, with the restriction that his budget should cover the purchase price.
-Adjusts the lifetime of his technologies.

## HOW TO USE IT

### Parameter sliders

The sliders (the parameters) can be set to the prefered values. 
-CostPriceRange: The range in which the costprice of a technology randomly is updated.
-Fuel price: The energy costs depends on the fuel price and the energy use. By changing the fuel price, the energy costs and therewith the profit of the greenhouse owner will change.
-ImproveSameTechnologyCounter: The number of times the same product of a Technology market is allowed to be improved in succession. This value prevents that always the same technology is improved, it introduces a randomness into the improvement procedure. Or and how fast a single technology will become dominant depends on this slider setting.
-The Stubborness factor: The degree a greenhouseowner weighs his Own Opinion relatively to his neighbors opinions about a technology. It expresses how easely a Greenhouse owner is convinced by his neighbors about a technology. The higher the Stubborness factor, the more equal the neighbors opinion is weighted as the own opinion. With a stubborness factor of zero, No greenhouseowner is influenced by his neighbors opinion and each owner will stick all the time to the same technology. This parameter value influences the diffusion of technologies.
-VeggiesMarketPrice: Price for which the greenhouse owner is able to sell an unit of Veggies. A change will influence the marginal revenue and therefore the profit of the greenhouse owner. (The same holds for FlowersMarketPrice)
-VeggiesPurchasePrice: The costs of a unit of crop seeds, the greenhouseowner has to invest before the actual production can be calculated. (The same holds for Flowers)

-NumberOfGreenhouseowners: Defines of course the number of greenhouseowners that the network will contain. The number is stable during each run because bankrupt greenhouseowners are instantly replaced by new greenhouseowners with basic settings.
-LifespanMin - Max: To each technology, randomly a lifespan is assigned that falls within the range. By using the sliders, the range can be changed. the same holds for the Costprice and the EnergyUse, for which also a minimum and maximum value can be chosen.

### Parameter sliders of Development styles
-DevelopmentStyle: Choser with which the prefered development style can be selected. 
-CostPriceCooperativeMultiplicator: It is plausible that cooperative development is more expensive than protected, isolated development. Limited cooperation will demand more coordination, contractual agreements and integration of designs, what will lead to higher costs. The value multiplies the Cosprice of technologies improved with Limited Cooperation. Initially at 1, there is no difference in the development costs.

### Parameter sliders of influence numbers

-InfluenceRange: It expresses the maximum improvement of a function. In the model, when a technology will be improved, a random-float number between 0 and this number will be add to the function. (..Main for the main function, ..Sec for the secundary functions)  

The climate is modelled as a vector with four components; Temperature, CO2, Humidity and Light intensity. A technoloy can influence multiple of this components. When creating technologies, these influences are generated using a vary-float: A float number, randomly picked between an upper and lower bound. 

### Parameter sliders of climate

-Each croptype has an ideal climate, the internal climate in which the actual crop yield equals the potential crop yield. The ideal climate of Veggies and Flowers can be adjusted.
-The external climate can be adjusted with the External sliders

## THINGS TO NOTICE


## EXTENSION SUGGESTIONS

-Energy use is not constant, but depends on the difference between the Ideal and External climate. This will result in a more realistic model, where the energy use increases during the winter and depends on the croptype.
-External climate fluctuations. The climate is not constant, but changes randomly over time, between boundaries determined by historical data.
-Fuelprice changes indogeneously, by a random function.
-Development of technologies depends on their popularity
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

die 1
false
0
Rectangle -7500403 true true 45 45 255 255
Circle -16777216 true false 129 129 42

die 2
false
0
Rectangle -7500403 true true 45 45 255 255
Circle -16777216 true false 69 69 42
Circle -16777216 true false 189 189 42

die 3
false
0
Rectangle -7500403 true true 45 45 255 255
Circle -16777216 true false 69 69 42
Circle -16777216 true false 129 129 42
Circle -16777216 true false 189 189 42

die 4
false
0
Rectangle -7500403 true true 45 45 255 255
Circle -16777216 true false 69 69 42
Circle -16777216 true false 69 189 42
Circle -16777216 true false 189 69 42
Circle -16777216 true false 189 189 42

die 5
false
0
Rectangle -7500403 true true 45 45 255 255
Circle -16777216 true false 69 69 42
Circle -16777216 true false 129 129 42
Circle -16777216 true false 69 189 42
Circle -16777216 true false 189 69 42
Circle -16777216 true false 189 189 42

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

flowers
false
1
Circle -2674135 true true 0 0 300

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

veggies
false
5
Circle -10899396 true true 0 0 300

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0RC8
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Experiment ImproveSameTechCounter and StubornnessFactor" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="50"/>
    <metric>RelativeProductionVeggies</metric>
    <steppedValueSet variable="StubbornnessFactor" first="0" step="0.2" last="1"/>
    <steppedValueSet variable="ImproveSameTechCounter" first="0" step="1" last="4"/>
  </experiment>
  <experiment name="Main experiment" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="150"/>
    <metric>RelativeProductionVeggies</metric>
    <metric>MeanProfitVeggies</metric>
    <metric>RelativeProductionFlowers</metric>
    <metric>MeanProfitFlowers</metric>
    <metric>NumberOfBankruptedGreenhouseowners</metric>
    <enumeratedValueSet variable="DevelopmentStyle">
      <value value="&quot;Protected development&quot;"/>
      <value value="&quot;Limited cooperation&quot;"/>
      <value value="&quot;Open source cooperation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="StubbornnessFactor" first="0.2" step="0.3" last="0.8"/>
    <steppedValueSet variable="ImproveSameTechCounter" first="0" step="1" last="3"/>
    <steppedValueSet variable="InfluenceRangeSec" first="0.04" step="0.02" last="0.1"/>
    <steppedValueSet variable="InfluenceRangeMain" first="0.04" step="0.04" last="0.16"/>
    <steppedValueSet variable="FuelPrice" first="0.4" step="0.2" last="0.8"/>
  </experiment>
  <experiment name="Experiment ImproveSameTechCounter" repetitions="25" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="150"/>
    <metric>RelativeProductionVeggies</metric>
    <metric>TechCounterVeggies</metric>
    <metric>RelativeProductionFlowers</metric>
    <metric>TechCounterFlowers</metric>
    <enumeratedValueSet variable="DevelopmentStyle">
      <value value="&quot;Protected development&quot;"/>
      <value value="&quot;Limited cooperation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="StubbornnessFactor" first="0.3" step="0.3" last="0.9"/>
    <steppedValueSet variable="ImproveSameTechCounter" first="0" step="1" last="4"/>
    <steppedValueSet variable="InfluenceRangeMain" first="0.05" step="0.05" last="0.1"/>
  </experiment>
  <experiment name="Long run Experiment" repetitions="10" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>RelativeProductionVeggies</metric>
    <metric>MeanProfitVeggies</metric>
    <metric>RelativeProductionFlowers</metric>
    <metric>MeanProfitFlowers</metric>
    <metric>NumberOfBankruptedGreenhouseowners</metric>
    <metric>NumberOfGreenhouseownersWithVeggies</metric>
    <metric>NumberOfGreenhouseownersWithFlowers</metric>
    <metric>TechCounterFlowers</metric>
    <metric>TechCounterVeggies</metric>
    <metric>TechCounterTotal</metric>
    <enumeratedValueSet variable="DevelopmentStyle">
      <value value="&quot;Protected development&quot;"/>
      <value value="&quot;Limited cooperation&quot;"/>
      <value value="&quot;Open source cooperation&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="InfluenceRangeSec" first="0.04" step="0.02" last="0.1"/>
    <steppedValueSet variable="InfluenceRangeMain" first="0.02" step="0.03" last="0.11"/>
    <enumeratedValueSet variable="ImproveSameTechCounter">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Experiment C" repetitions="5" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="150"/>
    <metric>RelativeProductionVeggies</metric>
    <metric>MeanProfitVeggies</metric>
    <metric>RelativeProductionFlowers</metric>
    <metric>MeanProfitFlowers</metric>
    <metric>NumberOfBankruptedGreenhouseowners</metric>
    <enumeratedValueSet variable="DevelopmentStyle">
      <value value="&quot;Protected development&quot;"/>
      <value value="&quot;Limited cooperation&quot;"/>
      <value value="&quot;Open source cooperation&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="StubbornnessFactor">
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ImproveSameTechCounter">
      <value value="0"/>
      <value value="2"/>
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="FuelPrice">
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="NumberOfGreenhouseowners">
      <value value="50"/>
      <value value="100"/>
      <value value="150"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CostPriceCooperativeMultiplicator">
      <value value="1"/>
      <value value="1.15"/>
      <value value="1.3"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
